@@ -384,6 +384,9 @@ function finishConnection (socket, noteId, socketId) {
   }
   const note = notes[noteId]
   const user = users[socketId]
+  if (!user) {
+    return failConnection(500, 'user not found', socket)
+  }
   // update user color to author color
   if (note.authors[user.userid]) {
     user.color = users[socket.id].color = note.authors[user.userid].color
@@ -710,7 +713,7 @@ function connection (socket) {
 
     // initialize user data
     // random color
-    let color = chance.color()
+    let color = chance.color({ format: 'hex' })
     // make sure color not duplicated or reach max random count
     if (notes[noteId]) {
       let randomcount = 0
@@ -723,7 +726,7 @@ function connection (socket) {
           }
         })
         if (found) {
-          color = chance.color()
+          color = chance.color({ format: 'hex' })
           randomcount++
         }
       } while (found && randomcount < maxrandomcount)
